package com.diagbot.client;

import com.diagbot.client.hystrix.TranServiceHystrix;
import com.diagbot.dto.DoctorInfoDTO;
import com.diagbot.dto.GetTopPatientInfoDTO;
import com.diagbot.dto.HospitalDeptInfoDTO;
import com.diagbot.dto.HospitalInfoDTO;
import com.diagbot.dto.LisConfigDTO;
import com.diagbot.dto.PatientInfoDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.TranFieldInfoDTO;
import com.diagbot.vo.DoctorInfoVO;
import com.diagbot.vo.GetTopPatientInfoVO;
import com.diagbot.vo.HospitalDeptInfoVO;
import com.diagbot.vo.HospitalInfoVO;
import com.diagbot.vo.LisHospitalCodeVO;
import com.diagbot.vo.PatientInfoVO;
import com.diagbot.vo.TranFieldInfoVO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;

/**
 * @Description: 调用信息对接层服务
 * @author: gaodm
 * @time: 2019/2/1 17:00
 */
@FeignClient(value = "tran-service", fallback = TranServiceHystrix.class)
public interface TranServiceClient {

    /**
     * 获取医生信息
     *
     * @param doctorInfoVo
     * @return
     */
    @PostMapping("/doctorInfo/getDoctorInfo")
    RespDTO<List<DoctorInfoDTO>> getDoctorInfo(@RequestBody DoctorInfoVO doctorInfoVo);

    /**
     * 获取科室信息
     *
     * @param hospitalDeptInfoVO
     * @return
     */
    @PostMapping("/hospitalDeptInfo/getHospitalDeptInfo")
    RespDTO<HospitalDeptInfoDTO> getHospitalDeptInfo(@RequestBody HospitalDeptInfoVO hospitalDeptInfoVO);

    /**
     * 获取医院信息
     *
     * @param hospitalInfoVO
     * @return
     */
    @PostMapping("/hospitalInfo/getHospitalInfo")
    RespDTO<List<HospitalInfoDTO>> getHospitalInfo(@RequestBody HospitalInfoVO hospitalInfoVO);
    /**
     * 匹配公表名
     * @param lisHospitalCodeVO
     * @return
     */
    @PostMapping("/tranLisConfig/getLisConfigByhospitalId")
    RespDTO<List<LisConfigDTO>> getLisConfigByhospitalId(@RequestBody LisHospitalCodeVO lisHospitalCodeVO);

    /**
     * 获取患者信息
     *
     * @param patientInfoVO
     * @return
     */
    @PostMapping("/patientInfo/getPatientInfo")
    RespDTO<PatientInfoDTO> getPatientInfo(@RequestBody PatientInfoVO patientInfoVO);

    /**
     * 获取页面顶部病人医生科室信息
     *
     * @param getTopPatientInfoVO
     * @return
     */
    @PostMapping("/patientInfo/getTopPatientInfo")
    RespDTO<GetTopPatientInfoDTO> getTopPatientInfo(@RequestBody GetTopPatientInfoVO getTopPatientInfoVO);


    /**
     * 根据uuid获取相关信息
     * @param tranFieldInfoVO
     * @return
     */
    @PostMapping("/tranFieldInfo/getInfoByUuid")
    RespDTO<List<TranFieldInfoDTO>> getInfoByUuid(@RequestBody TranFieldInfoVO tranFieldInfoVO);
}
